@@ -1,13 +1,13 @@
 package Net::DNS::RR::A;
 
 #
-# $Id: A.pm 1388 2015-09-07 12:28:16Z willem $
+# $Id: A.pm 1597 2017-09-22 08:04:02Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1388 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
 
 
 use strict;
+use warnings;
 use base qw(Net::DNS::RR);
 
 =head1 NAME
@@ -31,7 +31,6 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless defined $self->{address};
 	pack 'a4', $self->{address};
 }
 
@@ -39,7 +38,6 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless defined $self->{address};
 	$self->address;
 }
 
