@@ -1,9 +1,9 @@
 package Net::DNS::RR::DS;
 
 #
-# $Id: DS.pm 1597 2017-09-22 08:04:02Z willem $
+# $Id: DS.pm 1774 2020-03-18 07:49:22Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1774 $)[1];
 
 
 use strict;
@@ -66,7 +66,7 @@ my %digest = (
 	my %algbyval = reverse @algbyname;
 
 	my @algrehash = map /^\d/ ? ($_) x 3 : do { s/[\W_]//g; uc($_) }, @algbyname;
-	my %algbyname = @algrehash;    # work around broken cperl
+	my %algbyname = @algrehash;				# work around broken cperl
 
 	sub _algbyname {
 		my $arg = shift;
@@ -74,7 +74,7 @@ my %digest = (
 		$key =~ s/[\W_]//g;				# strip non-alphanumerics
 		my $val = $algbyname{$key};
 		return $val if defined $val;
-		return $key =~ /^\d/ ? $arg : croak "unknown algorithm $arg";
+		return $key =~ /^\d/ ? $arg : croak qq[unknown algorithm "$arg"];
 	}
 
 	sub _algbyval {
@@ -88,10 +88,10 @@ my %digest = (
 #
 {
 	my @digestbyname = (
-		'SHA-1'		  => 1,				# RFC3658
-		'SHA-256'	  => 2,				# RFC4509
-		'GOST-R-34.11-94' => 3,				# RFC5933
-		'SHA-384'	  => 4,				# RFC6605
+		'SHA-1'		  => 1,				# [RFC3658]
+		'SHA-256'	  => 2,				# [RFC4509]
+		'GOST-R-34.11-94' => 3,				# [RFC5933]
+		'SHA-384'	  => 4,				# [RFC6605]
 		);
 
 	my @digestalias = (
@@ -110,7 +110,7 @@ my %digest = (
 		$key =~ s/[\W_]//g;				# strip non-alphanumerics
 		my $val = $digestbyname{$key};
 		return $val if defined $val;
-		return $key =~ /^\d/ ? $arg : croak "unknown digest type $arg";
+		return $key =~ /^\d/ ? $arg : croak qq[unknown algorithm "$arg"];
 	}
 
 	sub _digestbyval {
@@ -125,8 +125,7 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 	my ( $data, $offset ) = @_;
 
 	my $rdata = substr $$data, $offset, $self->{rdlength};
-	$self->{digestbin} = unpack '@4 a*', $rdata;
-	@{$self}{qw(keytag algorithm digtype)} = unpack 'n C*', $rdata;
+	@{$self}{qw(keytag algorithm digtype digestbin)} = unpack 'n C2 a*', $rdata;
 }
 
 
@@ -141,8 +140,8 @@ sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	$self->_annotation( $self->babble ) if BABBLE && $self->{algorithm};
-	my @digest = split /(\S{64})/, $self->digest || '-';
-	my @rdata = ( @{$self}{qw(keytag algorithm digtype)}, @digest );
+	my @param = @{$self}{qw(keytag algorithm digtype)};
+	my @rdata = ( @param, split /(\S{64})/, $self->digest || '-' );
 }
 
 
@@ -196,7 +195,7 @@ sub digtype {
 sub digest {
 	my $self = shift;
 	return unpack "H*", $self->digestbin() unless scalar @_;
-	$self->digestbin( pack "H*", map /[^\dA-F]/i ? croak "corrupt hex" : $_, join "", @_ );
+	$self->digestbin( pack "H*", join "", map { /^"*([\dA-Fa-f]*)"*$/ || croak("corrupt hex"); $1 } @_ );
 }
 
 
@@ -220,14 +219,13 @@ sub create {
 
 	my ($type) = reverse split '::', $class;
 
-	my $kname = $keyrr->name;
 	my $flags = $keyrr->flags;
 	croak "Unable to create $type record for non-DNSSEC key" unless $keyrr->protocol == 3;
 	croak "Unable to create $type record for non-authentication key" if $flags & 0x8000;
 	croak "Unable to create $type record for non-ZONE key" unless ( $flags & 0x300 ) == 0x100;
 
 	my $self = new Net::DNS::RR(
-		name	  => $kname,				# per definition, same as keyrr
+		owner	  => $keyrr->owner,			# per definition, same as keyrr
 		type	  => $type,
 		class	  => $keyrr->class,
 		keytag	  => $keyrr->keytag,
@@ -236,14 +234,12 @@ sub create {
 		%args
 		);
 
-	my $owner = $self->{owner}->encode();
-	my $data = pack 'a* a*', $owner, $keyrr->_encode_rdata;
-
 	my $arglist = $digest{$self->digtype};
 	croak join ' ', 'digtype', $self->digtype('MNEMONIC'), 'not supported' unless $arglist;
 	my ( $object, @argument ) = @$arglist;
 	my $hash = $object->new(@argument);
-	$hash->add($data);
+	$hash->add( $keyrr->{owner}->canonical );
+	$hash->add( $keyrr->_encode_rdata );
 	$self->digestbin( $hash->digest );
 
 	return $self;
