@@ -1,9 +1,9 @@
 package Net::DNS::RR::LP;
 
 #
-# $Id: LP.pm 1528 2017-01-18 21:44:58Z willem $
+# $Id: LP.pm 1597 2017-09-22 08:04:02Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1528 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
 
 
 use strict;
@@ -32,7 +32,7 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	my $target = $self->{target} || return '';
+	my $target = $self->{target};
 	pack 'n a*', $self->preference, $target->encode();
 }
 
@@ -40,7 +40,7 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	my $target = $self->{target} || return '';
+	my $target = $self->{target};
 	join ' ', $self->preference, $target->string;
 }
 
