@@ -1,9 +1,9 @@
 package Net::DNS::RR::TSIG;
 
 #
-# $Id: TSIG.pm 1749 2019-07-21 09:15:55Z willem $
+# $Id: TSIG.pm 1774 2020-03-18 07:49:22Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1749 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1774 $)[1];
 
 
 use strict;
@@ -369,6 +369,7 @@ sub create {
 
 	} elsif ( scalar(@_) == 1 ) {
 		my $key = shift;				# ( keyname, key )
+		$class->_deprecate('create( $key_name, $key )');
 		return new Net::DNS::RR(
 			name => $karg,
 			type => 'TSIG',
@@ -710,10 +711,6 @@ needed for TSIG-GSS.
 Returns a TSIG RR constructed using the parameters in the specified
 key file, which is assumed to have been generated by dnssec-keygen.
 
-    $tsig = create Net::DNS::RR::TSIG( $keyname, $key );
-
-The two argument form is supported for backward compatibility.
-
 =head2 verify
 
     $verify = $tsig->verify( $data );
